API Documentation
=================

* :doc:`modules/ridge`
* :doc:`modules/quantile`
* :doc:`modules/kernels`
* :doc:`modules/risk`
* :doc:`modules/metrics`
* :doc:`modules/datasets`
* :doc:`modules/signal`
